const gulp = require('gulp-4.0.build');
const async = require('async');
const glob = require('glob');
const path = require('path');
const fs = require('fs');

const names = {CONFIGS: 'Configs', L10N: 'Localizations'};
const result = {CONFIGS: {}, L10N: {}};

gulp.task('globals', (done) => {
  glob('./src/**/*.json', {}, (err, files) => {
    const queue = files.map((file) => {
      return function (callback) {
        const info = path.parse(file);
        const key = info.dir.split('/').pop().toUpperCase();

        if (result[key] === undefined) {
          return callback();
        }

        fs.readFile(file, 'utf8', (err, content) => {
          if (err) {
            return callback(err);
          }

          try {
            result[key][info.name] = JSON.parse(content);
          } catch (err) {
            return callback(err);
          }

          callback(null);
        });
      };
    });

    async.series(queue, (err) => {
      if (err) {
        return done(err);
      }

      const data = [];
      const mdContent = [];

      Object.keys(result).map((key) => {
        data.push(`window.${key}=${JSON.stringify(result[key])};`);

        mdContent.push(`## ${names[key]}`);
        mdContent.push('`' + Object.keys(result[key]).join('`, `') + '`');
        mdContent.push('\n');
      });

      fs.readFile('./README.md', 'utf8', (err, content) => {
        fs.writeFile('./tmp/README.md', content + '\n\n' + mdContent.join('\n'), 'utf8', () => {
        });
      });

      fs.writeFile('./tmp/globals.js', data.join('\n'), 'utf8', (err) => done(err));
    });
  });
});
