const path = require('path');
const gulp = require('gulp-4.0.build');
const webpack = require('webpack');

const InjectHtmlPlugin = require('inject-html-webpack-plugin');

const packageJson = require('../package.json');

function getConfig(isProduction) {
  const plugins = [
    new InjectHtmlPlugin({
      filename: './src/index.html',
      output: './tmp/index.html',
      customInject: [
        {
          start: '<!-- start:title -->',
          end: '<!-- end:title -->',
          content: `<title>${packageJson.title}</title>`
        }
      ]
    }),
    new InjectHtmlPlugin({
      filename: './src/index.html',
      output: './tmp/index_preview.html',
      customInject: [
        {
          start: '<!-- start:title -->',
          end: '<!-- end:title -->',
          content: `<title>${packageJson.title}</title>`
        },
        {
          start: '<!-- start:dapi -->',
          end: '<!-- end:dapi -->',
          content: ''
        }
      ]
    })
  ];

  if (isProduction) {
    plugins.push(
      new webpack.optimize.UglifyJsPlugin({
        compress: {warnings: false},
        output: {comments: false}
      })
    );
  }

  return {
    entry: {
      app: './src/main.js'
    },
    output: {
      path: path.resolve(__dirname, '../tmp'),
      filename: '[name].js'
    },
    resolve: {
      extensions: ['.js', '.json'],
    },
    module: {
      loaders: [
        {
          test: /\.(jpe?g|png|otf|ttf|ttc|eot|woff(2)?)(\?[a-z0-9=&.]+)?$/,
          loaders: ['base64-inline-loader']
        },
        {
          test: /\.js$/,
          exclude: /node_modules/,
          loaders: ['babel-loader']
        },
        {
          test: /\.json$/,
          loaders: ['json-loader']
        }
      ]
    },
    plugins
  };
}

gulp.task('webpack:dev', (done) => {
  webpack(getConfig(false)).run((err, stats) => done());
});

gulp.task('webpack:build', (done) => {
  webpack(getConfig(true)).run((err, stats) => done());
});
