window.onerror = function (errorMsg, url, lineNumber) {
  document.body.innerHTML = '<h1>' + url + ':' + lineNumber + '</h1><pre>' + errorMsg + '<pre>';
};

import {title, version} from '../package.json';
import {atom} from 'playable-ads-libs';
atom.init(title, version);

import Boot from './states/boot';
import Game from './states/game';

let isGameStarted = false;

window.viewableChange = ({isViewable}) => {
  if (isViewable && !isGameStarted) {
    isGameStarted = true;

    const game = new Phaser.Game(960, 960 / (window.innerWidth / window.innerHeight), Phaser.CANVAS);

    game.state.add('boot', new Boot());
    game.state.add('game', new Game());

    game.state.start('boot');
  }
};

window.onReadyCallback = () => {
  // No need to listen to this event anymore
  window.dapi.removeEventListener('ready', window.onReadyCallback);

  if (window.dapi.isViewable()) {
    window.viewableChange({isViewable: true});
  } else {
    window.dapi.addEventListener('viewableChange', window.viewableChange);
  }
};

if (typeof window.dapi === 'undefined') {
  // This is a demo - run it now
  window.viewableChange({isViewable: true});
} else if (window.dapi.isReady()) {
  // This is a production - run it through dapi
  window.onReadyCallback();
} else {
  window.dapi.addEventListener('ready', window.onReadyCallback);
}
