// Libs
import {atom, urlParams, FontLoader, Config, L10n} from 'playable-ads-libs';

// Resources
import {fonts, images, spritesheets} from '../resources';

export default class Boot extends Phaser.State {
  preload() {
    atom.adStarted();

    // Load fonts
    Object.keys(fonts || {}).forEach((fontName) => {
      const match = fonts[fontName].match(/^data:font\/([a-z]+);/gi) || [];
      FontLoader.load(fonts[fontName], fontName, (match[1] === 'ttf') ? 'truetype' : 'opentype');
    });

    // Assign config & localization to game
    this.game.config = new Config(urlParams.config);
    this.game.l10n = new L10n(this.game.config.loc || urlParams.loc);

    // Game settings
    this.game.input.maxPointers = 1;
    this.game.scale.pageAlignHorizontally = true;
    this.game.scale.scaleMode = Phaser.ScaleManager.SHOW_ALL;
    this.game.scale.fullScreenScaleMode = Phaser.ScaleManager.SHOW_ALL;
    this.game.stage.disableVisibilityChange = true;

    // Init global variables
    this.game.score = 0;

    // Preload images
    Object.keys(images).forEach((imgName) => this.game.load.image(imgName, images[imgName]));

    // Preload spritesheets
    Object.keys(spritesheets).forEach((spriteName) => this.game.load.spritesheet(
      spriteName,
      spritesheets[spriteName].file,
      spritesheets[spriteName].frameWidth,
      spritesheets[spriteName].frameHeight
    ));

    // When images loading is complete - init config & localization
    this.load.onLoadComplete.addOnce(() => {
      // Draw screen to  show fake loading
      this.drawScreen();

      // Show game after X seconds
      setTimeout(() => this.game.state.start('game'), 1000);
    }, this);
  }

  drawScreen() {
    atom.loading();

    this.game.stage.backgroundColor = '#000000';

    const logo = this.game.add.sprite(this.game.world.centerX, this.game.world.centerY - 50, 'logo');
    logo.anchor.setTo(0.5);

    const spinner = this.game.add.sprite(this.game.world.centerX, this.game.world.centerY + 50, 'spinner');
    spinner.anchor.setTo(0.5);
    this.game.add.tween(spinner).to({angle: 360}, 1000, Phaser.Easing.Linear.None, true, false, false);
  }
}
